@@ -1098,6 +1098,11 @@ public:
 		return (at(3) << 8) | at(4);
 	}
 
+	int pcrPid() const
+	{
+		return ((at(8) & 0x1f) << 8) | at(9);
+	}
+
 	DvbDescriptor descriptors() const
 	{
 		return DvbDescriptor(getData() + 12, descriptorsLength);
